<?php

/* util.php - SynApp2 utility functions
**
   +----------------------------------------------------------------------+
   | SynApp2 Version 1                                                    |
   +----------------------------------------------------------------------+
   | Copyright (c) 2007 - 2010 Richard Howell. All rights reserved.       |
   +----------------------------------------------------------------------+
   | This source file is subject to version 1.01 of the SynApp2 license,  |
   | that is bundled with this package in the file LICENSE, and is        |
   | available through the world-wide-web at the following url:           |
   | http://www.synapp2.org/license/1_01.txt                              |
   | If you did not receive a copy of the SynApp2 license and are unable  |
   | to obtain it through the world-wide-web, please send a note to       |
   | license@synapp2.org so we can mail you a copy immediately.           |
   +----------------------------------------------------------------------+
   | Authors: Richard Howell                                              |
   |                                                                      |
   +----------------------------------------------------------------------+
**
** http://www.synapp2.org
**
** $Id: util.php,v 1.36 2010/03/23 19:04:38 richard Exp $
*/

function get_version($force = false)
{
    global $g_test_mode;

    return $g_test_mode && !$force ? '0.0.0' : '0.1.7' ;
}

////

function session_begin()
{
    if (!session_id())
    {
        session_start();
    }
}

session_begin();

function set_session_var($var_name, $var_value = null)
{
    if (!empty($var_name))
    {
        $_SESSION[$var_name] = $var_value;
    }
}

function get_session_var($var_name)
{
    return isset($_SESSION[$var_name]) ? $_SESSION[$var_name] : null ;
}

function unset_session_var($var_name)
{
    if (isset($_SESSION[$var_name]))
    {
        unset($_SESSION[$var_name]);
    }
}

////

$g_test_mode = false;

function set_test_mode($enable = true)
{
    global $g_test_mode;

    $g_test_mode = $enable ? true : false ;
}

////

$g_debug_msg = '';
$g_debug_msg_add_post_vars = true;

function add_debug_msg($mixed = null, $tag = null)
{
    global $g_debug_msg;
    global $g_debug_msg_add_post_vars;

    if ($g_debug_msg_add_post_vars)
    {
        $g_debug_msg_add_post_vars = false;
        fmt_debug($g_debug_msg, $_POST, '$_POST');
    }

    fmt_debug($g_debug_msg, $mixed, $tag);
}

function fmt_debug(&$markup, &$mixed, $tag)
{
    ob_start();

    if (!empty($tag))
    {
        print_r("\n");
        print_r($tag);
        print_r("\n");
    }

    if (!empty($mixed))
    {
        print_r($mixed);
    }

    $buf = encode_html_entities(ob_get_contents());

    ob_end_clean();

    if (!empty($buf))
    {
        $markup .= "<debug_msg>$buf</debug_msg>\n";
    }
}

function fmt_line(&$markup, $line)
{
    $markup .= $line . "\n";
}

////

function assert_handler($filename, $line, $expr)
{
    add_debug_msg("Expr: $expr\nFile: $filename\nLine: $line\n", '* Assertion Failed *');
}

assert_options(ASSERT_CALLBACK, 'assert_handler');
assert_options(ASSERT_ACTIVE, 1);
assert_options(ASSERT_WARNING, 0);
assert_options(ASSERT_QUIET_EVAL, 1);

////

require_once('dbx.php');

function &get_dbx()
{
    global $g_dbx;

    return $g_dbx;
}

function escape_sql_term($term)
{
    $dbx = get_dbx();

    return !empty($dbx) ? $dbx->escape_sql_term($term) : $term ;
}

////

function get_database_physical($alternate_appid = null, $host = null)
{
    global $g_access;

    assert($g_access);

    return !empty($g_access) ? $g_access->get_database_physical($alternate_appid, $host) : '' ;
}

////

function get_array_element(&$array_var, $key_value)
{
    return isset($array_var[$key_value]) ? $array_var[$key_value] : null ;
}

////

function encode_xml_entities($s)
{
    // build collection of entities to match
    //
    $table1 = get_html_translation_table(HTML_ENTITIES, ENT_QUOTES);

    // build collection of entities to replace (numeric entities)
    //
    foreach ($table1 as $k => $v)
    {
        $table1[$k] = "/$v/";

        //$c = @htmlentities($k, ENT_QUOTES, "UTF-8");
        $c = @htmlentities($k, ENT_QUOTES);

        $table2[$c] = "&#" . ord($k) . ";";
    }

    // each matched value in $table1 will be replaced with the corresponding value in $table2
    //
    $s = preg_replace($table1, $table2, $s);

    return $s;
}

function encode_html_entities($s)
{
    $value = '';

    if (isset($s))
    {
        if (is_array($s))
        {
            $value = array_map('encode_html_entities', $s);
        }
        else
        {
            $value = htmlentities($s, ENT_QUOTES);

            if ($value != $s)
            {
                $value = encode_xml_entities($value);
            }
        }
    }

    return $value;
}

////

function downloadFile($filename)
{
    if (!empty($filename) && file_exists($filename))
    {
        header("Pragma: public");
        header("Expires: 0");
        header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
        header("Content-Type: application/force-download");
        header("Content-Type: application/octet-stream");
        header("Content-Type: application/download");
        header("Content-Disposition: attachment; filename=" . basename($filename) . ";");
        header("Content-Transfer-Encoding: binary");
        header("Content-Length: " . filesize($filename));

        readfile("$filename");
    }
}

function writeFileContents($output, $lines_out)
{
    // return file_put_contents($output, $lines_out); // php 5

    $result = false;

    $h = fopen($output, 'wb+');

    if ($h)
    {
        $wresult = true;

        if (!empty($lines_out))
        {
            foreach ($lines_out as $line)
            {
                if (fwrite($h, $line) === false)
                {
                    $wresult = false;
                    break; // error
                }
            }
        }

        $result = $wresult && fclose($h);
    }

    return $result;
}

////

function get_work_dir()
{
    return './';
}

function get_apps_dir()
{
    return get_work_dir() . '../';
}

function get_app_dir($appid)
{
    return $appid ? (get_apps_dir() . "{$appid}/") : get_work_dir() ;
}

function get_config_dir()
{
    return get_apps_dir() . '_config_/';
}

////

function mkdir_app_dir($appid)
{
    $result = null;

    if (!empty($appid))
    {
        $apps_dir = get_apps_dir();

        if (is_dir($apps_dir))
        {
            $app_dir = get_app_dir($appid);

            if (!is_dir($app_dir))
            {
                mkdir($app_dir);
                chmod($app_dir, 0777);
            }

            if (is_dir($app_dir))
            {
                $result = $app_dir;
            }
        }
    }

    return $result;
}

////

?>
